==> typo3-6.0.4.tbz: www/typo3_src-6.0.4/typo3/sysext/filelist/Classes/FileListEditIconHookInterface.php <==
<?php
namespace TYPO3\CMS\Filelist;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2008 Steffen Kamper <info@sk-typo3.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * Interface for classes which hook into file list module and manipulateds edit icon array
 *
 * @author Steffen Kamper <info@sk-typo3.de>
 */
interface FileListEditIconHookInterface
{
	/**
	 * Modifies edit icon array
	 *
	 * @param array $cells Array of edit icons
	 * @param \TYPO3\CMS\Filelist\FileList $parentObject Parent object
	 * @return void
	 */
	public function manipulateEditIcons(&$cells, &$parentObject);

}

?>

==> typo3-6.1.0.tbz: www/typo3_src-6.1.0/typo3/sysext/filelist/Classes/FileListEditIconHookInterface.php <==
<?php
namespace TYPO3\CMS\Filelist;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2008-2013 Steffen Kamper <info@sk-typo3.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Interface for classes which hook into file list module and manipulateds edit icon array
 *
 * @author Steffen Kamper <info@sk-typo3.de>
 */
interface FileListEditIconHookInterface {

	/**
	 * Modifies edit icon array
	 *
	 * @param array $cells Array of edit icons
	 * @param \TYPO3\CMS\Filelist\FileList $parentObject Parent object
	 * @return void
	 */
	public function manipulateEditIcons(&$cells, &$parentObject);

}

?>
